@@ -31,9 +31,9 @@ void FileFetchJob::start()
 
 void FileFetchJob::doStart()
 {
-    for (const QString &filePath : qAsConst(m_urls)) {
+    for (const QString &filePath : std::as_const(m_urls)) {
         bool extractorRunning = false;
-        KFileMetaData::PropertyMap fileProperties;
+        KFileMetaData::PropertyMultiMap fileProperties;
 
         // UseRealtimeIndexing::Fallback: try DB first, then filesystem
         // UseRealtimeIndexing::Disabled: DB contents only
@@ -53,7 +53,9 @@ void FileFetchJob::doStart()
         KFileMetaData::UserMetaData umd(filePath);
 
         if (umd.isSupported()) {
-            prop = Baloo::Private::convertUserMetaData(umd);
+            using Attribute = KFileMetaData::UserMetaData::Attribute;
+            auto umdData = Baloo::Private::fetchUserMetaData(umd, Attribute::Tags | Attribute::Rating | Attribute::Comment | Attribute::OriginUrl);
+            prop = Baloo::Private::convertUserMetaData(umdData);
         } else {
             m_canEditAll = false;
         }
@@ -66,7 +68,7 @@ void FileFetchJob::doStart()
             fileProperties = m_extractor.properties();
             qCDebug(WIDGETS) << filePath << "  properties:" << fileProperties;
         }
-        prop.unite(Baloo::Private::toNamedVariantMap(fileProperties));
+        prop.insert(Baloo::Private::toNamedVariantMap(fileProperties));
 
         m_data << prop;
     }
@@ -83,3 +85,5 @@ bool FileFetchJob::canEditAll() const
 {
     return m_canEditAll;
 }
+
+#include "moc_filefetchjob.cpp"
