@@ -18,6 +18,7 @@
 #include <KShell>
 
 #include <QPair>
+#include <QSize>
 
 // Required includes for subDirectoriesCount():
 #ifdef Q_OS_WIN
@@ -101,7 +102,7 @@ void extractDerivedProperties(QVariantMap &data)
     const auto width = data.value(QStringLiteral("width"));
     const auto height = data.value(QStringLiteral("height"));
     if (!width.isNull() && !height.isNull()) {
-        data.insert(QStringLiteral("dimensions"), i18nc("width × height", "%1 × %2", width.toInt(), height.toInt()));
+        data.insert(QStringLiteral("dimensions"), QSize(width.toInt(), height.toInt()));
     }
 
     bool okLatitude;
@@ -122,11 +123,13 @@ public:
         : QObject(parent)
         , m_parent(parent)
         , m_readOnly(false)
+        , m_fetchJob(nullptr)
     {
     }
 
     ~FileMetaDataProviderPrivate()
     {
+        m_parent->cancel();
     }
 
     void insertEditableData();
@@ -155,6 +158,8 @@ public:
     QVariantMap m_data;
     Baloo::IndexerConfig m_config;
 
+    FileFetchJob *m_fetchJob;
+
 public Q_SLOTS:
     void slotFileFetchFinished(KJob *job);
 };
@@ -175,6 +180,10 @@ void FileMetaDataProviderPrivate::slotFileFetchFinished(KJob *job)
     m_readOnly = !fetchJob->canEditAll();
 
     insertEditableData();
+
+    // Not cancellable anymore
+    m_fetchJob = nullptr;
+
     Q_EMIT m_parent->loadingFinished();
 }
 
@@ -386,6 +395,9 @@ void FileMetaDataProviderPrivate::processFileItems()
         }
 
         auto job = new FileFetchJob(urls, canEdit, indexingMode, this);
+        // Can be cancelled
+        m_fetchJob = job;
+
         connect(job, &FileFetchJob::finished, this, &FileMetaDataProviderPrivate::slotFileFetchFinished);
         job->start();
 
@@ -396,12 +408,28 @@ void FileMetaDataProviderPrivate::processFileItems()
     }
 }
 
+void FileMetaDataProvider::cancel()
+{
+    if (d->m_fetchJob) {
+        auto job = d->m_fetchJob;
+        d->m_fetchJob = nullptr;
+        job->kill();
+    }
+}
+
 void FileMetaDataProvider::setItems(const KFileItemList &items)
 {
     d->m_fileItems = items;
     d->m_data.clear();
 
-    if (items.isEmpty()) {
+    refresh();
+}
+
+void FileMetaDataProvider::refresh()
+{
+    cancel();
+
+    if (d->m_fileItems.isEmpty()) {
         Q_EMIT loadingFinished();
     } else {
         d->processFileItems();
